触不可及 (豆瓣)
Description: 触不可及电影简介和剧情介绍,触不可及影评、图片、预告片、影讯、论坛、在线购票
Keywords: 触不可及,Intouchables,触不可及影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.24豆瓣电影Top250

# 触不可及 Intouchables (2011)

更新描述或海报

导演: 奥利维埃·纳卡什 / 埃里克·托莱达诺
编剧: 奥利维埃·纳卡什 / 埃里克·托莱达诺
主演: 弗朗索瓦·克鲁塞 / 奥玛·希 / 安娜·勒尼 / 奥德雷·弗勒罗 / 约瑟芬娜·德·摩 / 克洛蒂尔德·莫莱特 / 阿尔芭·贝露琪 / Cyril Mendy / 萨丽马特·卡马特 / Absa Diatou Toure / Grégoire Oestermann / Dominique Daguier / François Caron / Christian Ameri / 托马·索利韦尔
类型: 剧情 / 喜剧
制片国家/地区: 法国
语言: 法语
上映日期: 2011-11-02(法国)
片长: 112分钟
又名: 闪亮人生(港) / 逆转人生(台) / 无法触碰 / 最佳拍档 / 不可触碰 / 不可触摸 / Untouchable / The Intouchables
IMDb: tt1675434
豆瓣评分
引用
9.3
1040670人评价
5星
68.6%
4星
27.1%
3星
4.0%
2星
0.2%
1星
0.1%
好友评分
你关注的人看过这部作品的平均分
8.5
4人评价
好于 99% 喜剧片
好于 99% 剧情片
想看 看过
评价:
推荐

## 触不可及的剧情简介 · · · · · ·

因为一次跳伞事故，白人富翁菲利普Philippe（弗朗索瓦·克鲁塞 François Cluzet 饰）瘫痪在床，欲招聘一名全职陪护。由于薪酬高，应聘者云集，个个舌灿莲花，却无法打动他的心。直到黑人德希斯Driss（奥玛·赛 Omar Sy 饰）的出现才让他作出决定。德希斯刚从监狱出来，背负家庭重担，一心只想寻张辞退信以申领救济金，而且他明显对女助理的兴趣要远大于这份工作。但是菲利普还是一眼相中了这个小伙子。于是，德希斯开始了一个月的试用期。虽然舒适的豪宅环境让他倍感虚荣，但是他仍面临很多挑战：不仅要为菲利普作身体复健，还得给他洗浴、灌肠、拆信、穿丝袜等。起初，两人的思维方式与价值观大相径庭，但是，随着了解的不断深入，他们成为了朋友……
本片取材于真实事件，获2011年东京电影节最佳影片金麒麟奖，弗朗索瓦·克鲁塞与奥玛·赛分享影帝桂冠。 ©豆瓣

## 触不可及的演职员 · · · · · · ( 全部 26 )

- 奥利维埃·纳卡什 导演
- 埃里克·托莱达诺 导演
- 弗朗索瓦·克鲁塞 饰 Philippe
- 奥玛·希 饰 Driss
- 安娜·勒尼 饰 Yvonne
- 奥德雷·弗勒罗 饰 Magalie

## 触不可及的视频和图片 · · · · · · ( 预告片8 | 视频评论1 · 添加 | 图片1067 · 添加 )

## 触不可及的获奖情况 · · · · · · ( 全部 )

- 第70届金球奖
- 电影类 最佳外语片(提名)

- 第25届欧洲电影奖
- 观众选择奖(提名)
- 埃里克·托莱达诺 / 奥利维埃·纳卡什

- 第36届日本电影学院奖
- 最佳外语片

## 喜欢这部电影的人也喜欢 · · · · · ·

  肖申克的救赎

  阿甘正传

  当幸福来敲门

  心灵捕手

  三傻大闹宝莱坞

  摔跤吧！爸爸

  荒岛余生

  国王的演讲

  贫民窟的百万富翁

  叫我第一名

我要写短评

## 触不可及的短评 · · · · · · ( 全部 229606 条 )

热门 / 最新 / 好友

### 7360 有用 张天翼 看过 2012-02-27 22:33:01

对残障人士最大的尊重，就是不要把他们当做残障人士。尊重比爱和同情心更高等级

### 6969 有用 LORENZO 洛伦佐 看过 2012-02-16 21:05:30

我想每个人都至少有这么一个挚友，你和他/她在人生的拐点遇到，惊叹于彼此的不同或者相似，有过不少平淡无奇却值得纪念的时光，ta会将心比心，为你的哀伤扼腕，为你的快慰击节，更会在ta的心里，为你留下那么一块永恒的位置，任白云苍狗，风云变幻。

### 5359 有用 桃桃林林 看过 2012-02-13 22:37:33

音乐真棒，看到最后有些意犹未尽。很舒服的电影，故事有趣又会带些感动。两个完全不同世界的人，因为教育、知识、习惯等各种不同造成情节冲突及笑料；而彼此的影响和同化则是感动的部分。对于菲利普来说，有时需要的未必是小心翼翼的服侍，而是像对待普通人一样的无歧视对待。

### 4762 有用 Dr希鲁鲁克 看过 2012-07-23 22:35:48

给领导做一万件好事不如陪他做一件坏事

### 3274 有用 匡轶歌 看过 2012-02-18 00:41:41

开怀大笑一整场，最后却蓦然飙泪。身份、地位、财富、性格、教养、爱好、年龄，各方面皆如此悬殊的两人，磁场却契合完美。无论爱情友情，所谓好的、有爱的关系，是两个人都在关系里感到开心融合、自由释放、并因而成长。什么是灵魂伴侣？这，就是传说中的，灵魂伴侣。

> 更多短评 229606条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。

### 0 有用 CoCo陶可可 看过 2021-02-10 20:57:51

2021，007。如果有一天我也能那样开怀大笑，那该多好

我要写影评

## 触不可及的影评 · · · · · · ( 全部 3163 条 )

热门 / 最新 / 好友
十二 2012-04-09 11:08:45

## 不要以善之名行凶

这篇影评可能有剧透

这是一个真实的故事。 迷恋跳伞的富翁因事故造成脖子以下瘫痪，于是高薪聘请一位全职陪护，在诸多应聘者当中，他却出人意料的选择了一位毫无经验并且刚从监狱释放的混混。身边人都不理解，他给出的回答是：他总是忘记我瘫痪的事实，我要的就是这样的人，没有怜悯没有特殊对待... (展开)
9217 219 416回应 收起
D 2011-11-24 05:28:49

## 音乐超级棒！！！！

迫不及待等原声了。 列一下影片里找到的歌，按出场顺序。 Ludovico Einaudi – Fly Earth, Wind & Fire – September Frédéric Chopin – Nocturne en si bémol op. 9 n°1 Ludovico Einaudi – Writing poems Ludovico Einaudi – Una mattina Franz Schubert –... (展开)
6284 98 472回应 收起
oceandeep 2012-02-16 21:28:53

## 细数《触不可及》的欢快对白(看题目就知道有透剧)

这篇影评可能有剧透

不得不承认，Driss是个很自信，很有感染力的男人。 影片一开始，面试那一段，Driss这个小混混就把其他应聘者都比了下去。 看看那些有着各种文凭的“知识分子”是如何回到玛格丽的提问的 ：结巴的结巴，找不到词的乱讲。还记那句“很老，很老的妇人，她真的是……”，我还以为... (展开)
2439 207 291回应 收起
LORENZO 洛伦佐 2012-02-16 21:01:50

## 得缘今生遇见你

看完一直在思考打四星还是五星，冲动之下还是给了这部电影最高的评价。因为它就像收到的一封私人的小诗，有些粗劣的文笔，却浸润着满满的深情，字里行间诉说着，我曾如此信任依赖的你。 它说的是友情，是刚开始或多或少的某种吸引，到后来的泪和笑，到慢慢的熟悉、理解、信任... (展开)
1329 55 94回应 收起
灯塔 2012-02-17 10:07:44

## 知己难求

这篇影评可能有剧透

刚开始看到这部影片的时候并没有想那么多，纯属是想找一点娱乐，但看完以后，觉得内心暖暖的。 生活太孤独了，人生很寂寞，现在很多人经常看到自己网络账号上面有上百个好友，却找不到真正知心的。于是叹乎知己难求…… 知心，不是只有他知你，或者只有你知他，而是彼此互相... (展开)
572 27 48回应 收起
娘卷卷🌻 2012-12-20 23:51:35

## 更加清楚的曲目单-古典部分（不客气

影评里有根据片尾字幕整理的音乐列表，不过鉴于是法语，并不好搜索，看了评论，似乎很多人还是不知道哪个是哪个，不才大致梳理一下里面的古典曲目： 出片名时起，一直到黑人等待面试的时候：肖邦降b小调夜曲，作品第9号第一首，这是肖邦的第一首发表的夜曲，给大家一个内谁家云... (展开)
459 6 19回应 收起
哆啦A梦的姐姐 2012-03-01 20:49:33

## 无法触碰的是人心

Driss离开的那幕，我开始掉泪。 Driss重新回到phillipe身边，我就泪流满面了。 我开始想到人跟人之间的各种。说不清也道不明的各种。 每个人或许都在试图寻找，寻找跟自己心灵契合的那一个人。 有时候，这样一个人是你的朋友，那必然应该是一辈子的朋友。有时候，很幸运，他刚... (展开)
521 20 33回应 收起
小水洲 2012-02-23 23:38:56

## 《intouchable》让我欢笑——影片《 无法触及》浅评

曾经很喜欢法国电影的深度，但，浅略过几部后，发现那生活的真实感让人喘不过气来，于是，有了畏惧，敬，如传统礼仪中先生与学生之间的关系一样，虽看不到，可那透明的墙不言而喻。而影片《无法触及》则给我一种完全别样的感受，我想这才是真正的好电影。 有些凝重... (展开)
500 18 32回应 收起
巴斯特德 2012-05-12 21:27:07

## 无知交，不人生

影片改编自真实故事。 每当看到一部好的影片，笔者内心中总会涌动起一股写作的冲动，这种冲动很莫名，无论是因为通过灵魂得到了升华，还是重又感觉到了生活的美好，亦或是彻底的陷入了虚无主义的深渊等等。但更奇妙的是，有了冲动的时候往往却感到无从写起，因为... (展开)
268 11 10回应 收起
奇点 2011-12-05 03:26:53

## 午夜巴黎被比下去了

下定决心明天去买minuit a paris 的碟片，以为这将是我最近几年里看的最好的片子。可能是里面的作家吸引了我的眼光，lost generation in paris，简直就是一个梦幻的世界。我喜欢Gil的情绪，一个男人身上的柔软和恬静，在巴黎的雨里，夹杂着对于生活灵敏的嗅觉，成就了我心中绝... (展开)
166 37 35回应 收起

> 更多影评 3163篇

添加新讨论

## 讨论区 · · · · · ·

《触不可及》到底在哪能看？ | 来自无所事事的样子 | 92 回应 | 2022-11-21 20:55:22
不明白为什么要辞退他？ | 来自深深的海洋 | 6 回应 | 2022-11-16 09:29:45
所以这个老板是做什么生意的？怎么这么有钱啊！ | 来自chanson0127 | 6 回应 | 2022-11-15 19:07:56
未删减的哪有看？ | 来自YDYBA | 6 回应 | 2022-11-14 22:20:09
在哪看 | 来自Fairy |  | 2022-11-14 22:19:30

> 去这部影片的讨论区（全部483条）

## 关于《触不可及》的问题 · · · · · · ( 全部54个 )

- 菲利普为啥相中了德瑞斯来做护理呢？ 7人回答
- 为什么飞利浦不喜欢第二个佣人？ 18人回答

> 全部54个问题

## 在哪儿看这部电影 · · · · · ·

报错

- 咪咕视频 VIP免费观看
- 腾讯视频 VIP免费观看
- 哔哩哔哩 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【内牛满面】 (影志)
- 那些牛叉闪闪的片子 (家庭种菜笔记)
- 【豆瓣五星电影集中营】(2/3) (影志)
- 2011新电影（这些，可以期待） (桃桃林林)

## 谁在看这部电影 · · · · · ·

- 筱夏1021
  3分钟前 看过
- L.J.Y
  4分钟前 看过
- 不是很想有名字
  4分钟前 看过

1676650人看过 / 595765人想看

订阅触不可及的评论:
feed: rss 2.0